package cases

import (
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/utils"
	"github.com/go-xorm/xorm"
	"strconv"
)

// 时间范围
const (
	ALL 				= -1 // 全部
	TODAY 			= 0 // 今天
	THIS_WEEK 	= 1 // 本周
	THIS_MONTH 	= 2 // 本月
	THIS_YEAR  	= 3 // 今年
)

// 星期
const (
	MONDAY      = 1 // 星期一
	TUESDAY			= 2 // 星期二
	WEDNESDAY   = 3 // 星期三
	THURSDAY		= 4 // 星期四
	FRIDAY			= 5 // 星期五
	SATURDAY		= 6 // 星期六
	SUNDAY			= 7 // 星期天
)

// CaseDAO 当前数据库操作对象
type SigninDAO struct {
	ctx *utils.Context
	db  *xorm.Session
}

// NewCaseDAO New Inst
func NewSigninDAO(ctx *utils.Context) *SigninDAO {
	return &SigninDAO{
		ctx: ctx,
		db:  ctx.DB,
	}
}

// CaseInfo 案场
type SigninInfo struct {
	model.TaCheckinRecord  `xorm:"extends"`
	//CreateUserName string
}

/**
	 GetSigninWhere 根据条件查询签到记录
			 条件:
					 selectType: 今天,本周,本月,今年,全部
					 caseid: 案场ID

		ALL 				= -1 // 全部
		TODAY 			= 0 // 今天
		THIS_WEEK 	= 1 // 本周
		THIS_MONTH 	= 2 // 本月
		THIS_YEAR  	= 3 // 今年


 **/
 func (m *SigninDAO) GetSigninWhere(selectType int,caseid string,page, pageSize int)([] SigninInfo,error){
	var signin []SigninInfo
	var sql string
	switch selectType {
		case ALL:
			sql = `select * from ta_checkin_record ORDER BY create_date DESC limit ` + strconv.Itoa((page-1)*pageSize) + `, ` + strconv.Itoa(pageSize)
		case TODAY:
			sql = `select * from ta_checkin_record where to_days(create_date) = to_days(now()) ORDER BY create_date DESC limit` + strconv.Itoa((page-1)*pageSize) + `, ` + strconv.Itoa(pageSize)
		case THIS_WEEK:
			sql = `SELECT * FROM ta_checkin_record WHERE YEARWEEK(date_format(create_date,'%Y-%m-%d')) = YEARWEEK(now()) ORDER BY create_date DESC limit` + strconv.Itoa((page-1)*pageSize) + `, ` + strconv.Itoa(pageSize)
		case THIS_MONTH:
			sql = `SELECT * FROM ta_checkin_record WHERE DATE_FORMAT(create_date,'%Y%m') = DATE_FORMAT(CURDATE(),'%Y%m') ORDER BY create_date DESC limit` + strconv.Itoa((page-1)*pageSize) + `, ` + strconv.Itoa(pageSize)
		case THIS_YEAR:
			sql = `select * from ta_checkin_record where YEAR(create_date)=YEAR(NOW()) ORDER BY create_date DESC limit` + strconv.Itoa((page-1)*pageSize) + `, ` + strconv.Itoa(pageSize)
	}
	
	err := m.db.Sql(sql).Find(&signin)
	return signin,err
 }


 



